summaryrefslogtreecommitdiff
path: root/nuttx/configs/samv71-xult/src/sam_wm8904.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/samv71-xult/src/sam_wm8904.c')
-rw-r--r--nuttx/configs/samv71-xult/src/sam_wm8904.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/nuttx/configs/samv71-xult/src/sam_wm8904.c b/nuttx/configs/samv71-xult/src/sam_wm8904.c
index cd10d72ff..fb25cd506 100644
--- a/nuttx/configs/samv71-xult/src/sam_wm8904.c
+++ b/nuttx/configs/samv71-xult/src/sam_wm8904.c
@@ -70,13 +70,13 @@
* Private Types
****************************************************************************/
-struct samv7xult_mwinfo_s
+struct samv71xult_mwinfo_s
{
/* Standard MW8904 interface */
struct wm8904_lower_s lower;
/* Extensions for the samv7xult board */
wm8904_handler_t handler;
FAR void *arg;
@@ -113,7 +113,7 @@ static bool wm8904_enable(FAR const struct wm8904_lower_s *lower,
* by the driver and is presumed to persist while the driver is active.
*/
-static struct samv7xult_mwinfo_s g_wm8904info =
+static struct samv71xult_mwinfo_s g_wm8904info =
{
.lower =
{
@@ -70,13 +70,13 @@
/* Standard MW8904 interface */
struct wm8904_lower_s lower;
- /* Extensions for the samv7xult board */
+ /* Extensions for the samv71xult board */
wm8904_handler_t handler;
FAR void *arg;